# A nodejs logger for AWS Lambda
* Writes logs to stdout using console.log
* Logs in JSON format
* Supports log levels: DEBUG, INFO, WARN, ERROR and OFF
* Defaults to log level INFO
* Built using typescript and includes types

```typescript
import { APIGatewayEvent } from 'aws-lambda';
import { log } from 'pn-lambda-logger';
import { ok } from '../aws/response';

export const healthCheck = async (event: APIGatewayEvent, context: AWSLambda.Context, cb: AWSLambda.Callback) => {

  // Will not show debug messages since default log.level = INFO
  log.debug({ message: 'Debug message' });

  // Message is mandatory
  log.info({ message: 'My message' });

  // xRequestId is optional
  log.warn({ message: 'My message', xRequestId: 'some-external-id' });

  // Context and xRequestId are optional
  log.error({ message: 'My message', context, xRequestId: 'some-external-id' });

  // Context and xRequestId are optional
  log.error({ message: 'My message', context, xRequestId: 'some-external-id', customProp1: 'custom property', customProp2: 42, customProp3: { a: 'more', complex: 'property' } });

  cb(null, ok({ status: 'UP' }));
};
```

```typescript
  // To show debug messages set level to DEBUG
  log.level = LogLevels.DEBUG;

  log.debug({ message: 'Debug message' });
};
```